@@ -36,7 +36,7 @@
 #include <libbonobo.h>
 #include <login-helper/login-helper.h>
 
-#include <gdk-pixbuf/gdk-pixbuf-io.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
